@@ -64,7 +64,7 @@ test_that("worldmet2meteoland works", {
     "sf"
   )
   expect_identical(nrow(test_complete_no_changes), nrow(test_res))
-  expect_identical(names(test_complete_no_changes), c(names(test_res), 'aspect', 'slope'))
+  expect_identical(names(test_complete_no_changes), c(names(test_res), 'PET','aspect', 'slope'))
   expect_identical(test_complete_no_changes$MinTemperature, test_res$MinTemperature)
   expect_false(
     identical(test_res$Radiation, test_complete_no_changes$Radiation)
@@ -128,7 +128,7 @@ test_that("meteospain2meteoland works", {
     "sf"
   )
   expect_identical(nrow(test_complete_no_changes), nrow(test_res))
-  expect_identical(names(test_complete_no_changes), c(names(test_res), 'aspect', 'slope'))
+  expect_identical(names(test_complete_no_changes), c(names(test_res),'PET', 'aspect', 'slope'))
   expect_identical(test_complete_no_changes$MinTemperature, test_res$MinTemperature)
   expect_false(
     identical(test_res$MeanRelativeHumidity, test_complete_no_changes$MeanRelativeHumidity)
@@ -148,7 +148,7 @@ test_that("meteospain2meteoland works", {
     "sf"
   )
   expect_identical(nrow(test_complete_all), nrow(test_res))
-  expect_identical(names(test_complete_all), c(names(test_res), 'aspect', 'slope'))
+  expect_identical(names(test_complete_all), c(names(test_res), 'PET','aspect', 'slope'))
   expect_identical(test_complete_all$MinTemperature, test_res$MinTemperature)
   expect_true(any(!is.na(test_complete_all$MeanRelativeHumidity)))
   expect_true(any(!is.na(test_complete_all$MinRelativeHumidity)))
@@ -192,7 +192,7 @@ test_that("meteospain2meteoland works", {
     "sf"
   )
   expect_identical(nrow(test_subdaily_complete), nrow(test_subdaily))
-  expect_identical(names(test_subdaily_complete), c(names(test_subdaily), 'aspect', 'slope'))
+  expect_identical(names(test_subdaily_complete), c(names(test_subdaily), 'PET', 'aspect', 'slope'))
   expect_identical(test_subdaily_complete$MinTemperature, test_subdaily$MinTemperature)
   expect_false(
     identical(test_subdaily$MeanRelativeHumidity, test_subdaily_complete$MeanRelativeHumidity)
@@ -226,7 +226,7 @@ test_that("meteospain2meteoland works with subdaily fringe cases", {
     "sf"
   )
   expect_identical(nrow(test_subdaily_complete), nrow(test_subdaily))
-  expect_identical(names(test_subdaily_complete), c(names(test_subdaily), 'aspect', 'slope'))
+  expect_identical(names(test_subdaily_complete), c(names(test_subdaily),'PET', 'aspect', 'slope'))
   expect_identical(test_subdaily_complete$MinTemperature, test_subdaily$MinTemperature)
   expect_false(
     identical(test_subdaily$MeanRelativeHumidity, test_subdaily_complete$MeanRelativeHumidity)
